@@ -17,11 +17,11 @@ use List::Util qw/shuffle/;
 use Moose;
 use namespace::autoclean;
 
-extends 'HPC::Runner';
-extends 'HPC::Runner::Slurm';
+extends 'HPC::Runner::Scheduler';
+#extends 'HPC::Runner::Slurm';
 with 'MooseX::SimpleConfig';
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 # For pretty man pages!
 $ENV{TERM}='xterm-256color';
@@ -54,8 +54,6 @@ has 'queue' => (
     is => 'rw',
     isa => 'Str|Undef',
     required => 0,
-    #default => 'adserial',
-    #default => '',
     documentation => q{PBS queue for job submission. Defaults is none, pbs decides.},
     predicate => 'has_queue',
     clearer => 'clear_queue',
@@ -63,6 +61,9 @@ has 'queue' => (
 
 has '+partition' =>(
     isa => 'Str | Undef',
+    #alias => 'queue',
+    #predicate => 'has_queue',
+    #clearer => 'clear_queue',
 );
 
 =head2 walltime
@@ -177,7 +178,7 @@ sub run {
 sub get_nodes {
     my($self) = @_;
 
-    $self->partition($self->queue) if $self->partition eq "";
+    #$self->partition($self->queue) if $self->partition eq "";
 
     $DB::single=2;
 
@@ -271,6 +272,7 @@ sub submit_slurm{
 
 
 __PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
